==> deepin-fcitx5configtool-plugin_6.0.8.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-fcitx5configtool-plugin_6.0.12.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>الإضافات</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>الإعدادات المتقدمة</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>&quot;الإعدادات المتقدمة&quot; صالحة فقط للطريقة المدخلة التي تعتمد على إعدادات النظام، وإذا كانت الطريقة المدخلة تحتوي على إعدادات خاصة، فإن هذه الإعدادات الخاصة ستكون السائدة.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation>الإعدادات العالمية</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation>الإضافات</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation>الرجاء إدخال خ Pendat baru</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation>التحرك للأعلى</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation>التحرك للأسفل</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation>إزالة</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation>إضافة طريقة مدخلة</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation>البحث</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation>ابحث عن المزيد في متجر التطبيقات</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation>إضافة</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>إدارة طريقة المدخلة</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation>إضافة طريقة مدخلة</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>الإجراءات السريعة</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation>استعادة القيم الافتراضية</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation>التنقل بين طرق المدخلة</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation>تشغيل أو إيقاف طرق المدخلة</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation>الرجاء إدخال إجراء مدخلة جديد</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>يُ Turning on or off the currently used input method. If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>طرق المدخلة</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>إدارة طريقة المدخلة، إجراءات المدخلة السريعة، الإعدادات المتقدمة</translation>
    </message>
</context>
</TS>
